@@ -1,49 +1,32 @@
 /*
-  Copyright (c) 2000,2001,2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Kevin Krammer, krake@kdab.com
-  Author: Sergio Martins, sergio.martins@kdab.com
+  SPDX-FileCopyrightText: 2000, 2001, 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Kevin Krammer <krake@kdab.com>
+  SPDX-FileContributor: Sergio Martins <sergio@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef EVENTVIEWS_AGENDAVIEW_H
-#define EVENTVIEWS_AGENDAVIEW_H
+#pragma once
 
-#include "eventviews_export.h"
 #include "eventview.h"
+#include "eventviews_export.h"
 #include "viewcalendar.h"
 
 #include <KCalendarCore/Todo>
 
-#include <QFrame>
+#include <memory>
 
 class KConfig;
 
 class QSplitter;
 
-namespace EventViews {
-#ifndef EVENTVIEWS_NODECOS
-namespace CalendarDecoration {
+namespace EventViews
+{
+namespace CalendarDecoration
+{
 class Decoration;
 }
-#endif
 
 class TimeLabels;
 class TimeLabelsZone;
@@ -52,14 +35,13 @@ class Agenda;
 class AgendaItem;
 class AgendaView;
 
-class EventIndicator : public QFrame
+class EventIndicatorPrivate;
+
+class EventIndicator : public QWidget
 {
     Q_OBJECT
 public:
-    enum Location {
-        Top,
-        Bottom
-    };
+    enum Location { Top, Bottom };
     explicit EventIndicator(Location loc = Top, QWidget *parent = nullptr);
     ~EventIndicator() override;
 
@@ -72,10 +54,11 @@ protected:
     bool eventFilter(QObject *, QEvent *) override;
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<EventIndicatorPrivate> const d;
 };
 
+class AgendaViewPrivate;
+
 /**
   AgendaView is the agenda-like view that displays events in a single
   or multi-day view.
@@ -84,9 +67,9 @@ class EVENTVIEWS_EXPORT AgendaView : public EventView
 {
     Q_OBJECT
 public:
-    explicit AgendaView(const PrefsPtr &preferences, const QDate &start, const QDate &end, bool isInteractive, bool isSideBySide = false, QWidget *parent = nullptr);
+    explicit AgendaView(const PrefsPtr &preferences, QDate start, QDate end, bool isInteractive, bool isSideBySide = false, QWidget *parent = nullptr);
 
-    explicit AgendaView(const QDate &start, const QDate &end, bool isInteractive, bool isSideBySide = false, QWidget *parent = nullptr);
+    explicit AgendaView(QDate start, QDate end, bool isInteractive, bool isSideBySide = false, QWidget *parent = nullptr);
 
     ~AgendaView() override;
 
@@ -143,7 +126,7 @@ public:
 
     /**
      * Return calendar object for a concrete incidence.
-     * this function is able to use multiple calenders
+     * this function is able to use multiple calendars
      * TODO: replace EventsView::calendar()
      */
     virtual KCalendarCore::Calendar::Ptr calendar2(const KCalendarCore::Incidence::Ptr &incidence) const;
@@ -164,13 +147,13 @@ public:
     void enableAgendaUpdate(bool enable);
     void setIncidenceChanger(Akonadi::IncidenceChanger *changer) override;
 
-    void zoomInHorizontally(const QDate &date = QDate());
-    void zoomOutHorizontally(const QDate &date = QDate());
+    void zoomInHorizontally(QDate date = QDate());
+    void zoomOutHorizontally(QDate date = QDate());
 
     void zoomInVertically();
     void zoomOutVertically();
 
-    void zoomView(const int delta, const QPoint &pos, const Qt::Orientation orient = Qt::Horizontal);
+    void zoomView(const int delta, QPoint pos, const Qt::Orientation orient = Qt::Horizontal);
 
     void clearTimeSpanSelection();
 
@@ -203,8 +186,6 @@ protected:
 
     void removeIncidence(const KCalendarCore::Incidence::Ptr &inc);
 
-    void resizeEvent(QResizeEvent *resizeEvent) override;
-
 public Q_SLOTS:
     void updateView() override;
     void updateConfig() override;
@@ -228,38 +209,34 @@ protected Q_SLOTS:
     */
     void updateEventIndicators();
     void scheduleUpdateEventIndicators();
-    void updateDayLabelSizes();
 
     void alignAgendas();
 
+protected:
+    void showEvent(QShowEvent *showEvent) override;
+
 private Q_SLOTS:
-    void slotIncidenceSelected(const KCalendarCore::Incidence::Ptr &incidence, const QDate &date);
-    void slotShowIncidencePopup(const KCalendarCore::Incidence::Ptr &incidence, const QDate &date);
+    void slotIncidenceSelected(const KCalendarCore::Incidence::Ptr &incidence, QDate date);
+    void slotShowIncidencePopup(const KCalendarCore::Incidence::Ptr &incidence, QDate date);
     void slotEditIncidence(const KCalendarCore::Incidence::Ptr &incidence);
     void slotShowIncidence(const KCalendarCore::Incidence::Ptr &incidence);
     void slotDeleteIncidence(const KCalendarCore::Incidence::Ptr &incidence);
 
 private:
-    void init(const QDate &start, const QDate &end);
+    void init(QDate start, QDate end);
     bool filterByCollectionSelection(const KCalendarCore::Incidence::Ptr &incidence);
     void setupTimeLabel(TimeLabels *timeLabel);
     bool displayIncidence(const KCalendarCore::Incidence::Ptr &incidence, bool createSelected);
 
-#ifndef EVENTVIEWS_NODECOS
-    typedef QList<EventViews::CalendarDecoration::Decoration *> DecorationList;
-    bool loadDecorations(const QStringList &decorations, DecorationList &decoList);
-    void placeDecorationsFrame(QFrame *frame, bool decorationsFound, bool isTop);
-    void placeDecorations(EventViews::AgendaView::DecorationList &decoList, const QDate &date, QWidget *labelBox, bool forWeek);
-#endif
-
     friend class TimeLabelsZone;
+    friend class MultiAgendaViewPrivate;
     friend class MultiAgendaView;
     Agenda *agenda() const;
     Agenda *allDayAgenda() const;
+
 private:
-    class Private;
-    Private *const d;
+    friend class AgendaViewPrivate;
+    std::unique_ptr<AgendaViewPrivate> const d;
 };
 }
 
-#endif
