@@ -20,7 +20,6 @@
 #include "calendarview_debug.h"
 #include <KCalendarCore/OccurrenceIterator>
 #include <KCheckableProxyModel>
-#include <KHolidays/HolidayRegion>
 #include <KLocalizedString>
 #include <QIcon>
 
@@ -227,10 +226,8 @@ MonthView::MonthView(NavButtonsVisibility visibility, QWidget *parent)
 MonthView::~MonthView()
 {
     if (calendar()) {
-        calendar()->unregisterObserver(d);
+        calendar()->unregisterObserver(d.get());
     }
-
-    delete d;
 }
 
 void MonthView::updateConfig()
@@ -440,7 +437,7 @@ KHolidays::Holiday::List MonthView::holidays(QDate startDate, QDate endDate)
 {
     KHolidays::Holiday::List holidays;
     auto const regions = CalendarSupport::KCalPrefs::instance()->mHolidays;
-    for (auto const r : regions) {
+    for (auto const &r : regions) {
         KHolidays::HolidayRegion region(r);
         if (region.isValid()) {
             holidays += region.holidays(startDate, endDate);
@@ -516,7 +513,7 @@ void MonthView::reloadIncidences()
     }
 
     // add holidays
-    for (auto const h : holidays(actualStartDateTime().date(), actualEndDateTime().date())) {
+    for (auto const &h : holidays(actualStartDateTime().date(), actualEndDateTime().date())) {
         if (h.dayType() == KHolidays::Holiday::NonWorkday) {
             MonthItem *holidayItem = new HolidayMonthItem(d->scene, h.observedStartDate(), h.observedEndDate(), h.name());
             d->scene->mManagerList << holidayItem;
@@ -581,9 +578,9 @@ void MonthView::setCalendar(const Akonadi::ETMCalendar::Ptr &cal)
     Q_ASSERT(cal);
 
     if (calendar()) {
-        calendar()->unregisterObserver(d);
+        calendar()->unregisterObserver(d.get());
     }
 
     EventView::setCalendar(cal);
-    calendar()->registerObserver(d);
+    calendar()->registerObserver(d.get());
 }
